@@ -1312,7 +1312,15 @@ BOOL sCommand_expand_env_redirect(sCommand* command, sObject* nextin, sRunInfo*
         int i;
         for(i=0; i<command->mRedirectsNum; i++) {
             char* fname = command->mRedirectsFileNames[i];
-            if(fname[0] == PARSER_MAGIC_NUMBER_ENV) {
+            BOOL env = FALSE;
+            char* p = fname;
+            while(*p) {
+                if(*p == PARSER_MAGIC_NUMBER_ENV) {
+                    env = TRUE;
+                }
+                p++;
+            }
+            if(env) {
                 char* expanded_str;
                 BOOL expand_double_dollar;
                 if(!expand_env_to_command(ALLOC &expanded_str, fname, command, runinfo, nextin, &expand_double_dollar)) {
