@@ -59,11 +59,11 @@ BOOL cmd_each(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
 
             int i;
-            for(i=0; i<vector_size(SFD(nextin).fdbuf.mLines); i+=number) {
+            for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines); i+=number) {
                 fd_clear(nextin2);
 
                 int j;
-                for(j=0; j<number && i+j<vector_size(SFD(nextin).fdbuf.mLines); j++)
+                for(j=0; j<number && i+j<vector_count(SFD(nextin).fdbuf.mLines); j++)
                 {
                     char* str = vector_item(SFD(nextin).fdbuf.mLines, i+j);
                     if(!fd_write(nextin2, str, strlen(str))) {
@@ -99,7 +99,7 @@ BOOL cmd_each(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
 
             int i;
-            for(i=0; i<vector_size(SFD(nextin).fdbuf.mLines); i++) {
+            for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines); i++) {
                 fd_clear(nextin2);
 
                 char* str = vector_item(SFD(nextin).fdbuf.mLines, i);
@@ -159,9 +159,9 @@ BOOL cmd_join(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             field = " ";
         }
 
-        if(vector_size(SFD(nextin).fdbuf.mLines) > 0) {
+        if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
             int i;
-            for(i=0; i<vector_size(SFD(nextin).fdbuf.mLines)-1; i++) {
+            for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines)-1; i++) {
                 sObject* line = STRING_NEW_STACK(vector_item(SFD(nextin).fdbuf.mLines, i));
                 string_chomp(line);
                 if(!fd_write(nextout, string_c_str(line), string_length(line))) {
@@ -230,7 +230,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         fd_split(nextin, lf);
 
-        if(vector_size(SFD(nextin).fdbuf.mLines) > 0) {
+        if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
             int i;
             for(i=1; i<command->mArgsNumRuntime; i++) {
                 char* arg = command->mArgsRuntime[i];
@@ -256,19 +256,19 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     int second = atoi(buf2);
 
                     if(first < 0) {
-                        first += vector_size(SFD(nextin).fdbuf.mLines);
+                        first += vector_count(SFD(nextin).fdbuf.mLines);
                         if(first < 0) first = 0;
                     }
                     if(second < 0) {
-                        second += vector_size(SFD(nextin).fdbuf.mLines);
+                        second += vector_count(SFD(nextin).fdbuf.mLines);
                         if(second < 0) second = 0;
                     }
-                    if(first >= vector_size(SFD(nextin).fdbuf.mLines)) {
-                        first = vector_size(SFD(nextin).fdbuf.mLines) -1;
+                    if(first >= vector_count(SFD(nextin).fdbuf.mLines)) {
+                        first = vector_count(SFD(nextin).fdbuf.mLines) -1;
                         if(first < 0) first = 0;
                     }
-                    if(second >= vector_size(SFD(nextin).fdbuf.mLines)) {
-                        second = vector_size(SFD(nextin).fdbuf.mLines) -1;
+                    if(second >= vector_count(SFD(nextin).fdbuf.mLines)) {
+                        second = vector_count(SFD(nextin).fdbuf.mLines) -1;
                         if(second < 0) second = 0;
                     }
 
@@ -323,11 +323,11 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     int num = atoi(arg);
 
                     if(num < 0) {
-                        num += vector_size(SFD(nextin).fdbuf.mLines);
+                        num += vector_count(SFD(nextin).fdbuf.mLines);
                         if(num < 0) num = 0;
                     }
-                    if(num >= vector_size(SFD(nextin).fdbuf.mLines)) {
-                        num = vector_size(SFD(nextin).fdbuf.mLines) -1;
+                    if(num >= vector_count(SFD(nextin).fdbuf.mLines)) {
+                        num = vector_count(SFD(nextin).fdbuf.mLines) -1;
                         if(num < 0) num = 0;
                     }
 
@@ -532,10 +532,10 @@ BOOL cmd_sort(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         if(sCommand_option_item(command, "-shuffle")) {
             fd_split(nextin, lf);
 
-            if(vector_size(SFD(nextin).fdbuf.mLines) > 0) {
-                int* shuffle_num = MALLOC(sizeof(int)*vector_size(SFD(nextin).fdbuf.mLines));
+            if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
+                int* shuffle_num = MALLOC(sizeof(int)*vector_count(SFD(nextin).fdbuf.mLines));
                 int i;
-                for(i=0;i<vector_size(SFD(nextin).fdbuf.mLines); i++) {
+                for(i=0;i<vector_count(SFD(nextin).fdbuf.mLines); i++) {
                     shuffle_num[i] = rand() % 2560;
                 }
 
@@ -547,7 +547,7 @@ BOOL cmd_sort(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                 FREE(shuffle_num);
 
-                for(i=0; i<vector_size(SFD(nextin).fdbuf.mLines); i++) {
+                for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines); i++) {
                     char* line = vector_item(SFD(nextin).fdbuf.mLines, i);
                     if(!fd_write(nextout, line, strlen(line))) {
                         err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
@@ -567,14 +567,14 @@ BOOL cmd_sort(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         else if(command->mBlocksNum == 1) {
             fd_split(nextin, lf);
 
-            if(vector_size(SFD(nextin).fdbuf.mLines) > 0) {
+            if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
                 sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
                 if(!vector_sort_cancelable(SFD(nextin).fdbuf.mLines, sort_fun, runinfo, nextin2, nextout)) {
                     return FALSE;
                 }
 
                 int i;
-                for(i=0; i<vector_size(SFD(nextin).fdbuf.mLines); i++) {
+                for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines); i++) {
                     char* line = vector_item(SFD(nextin).fdbuf.mLines, i);
                     if(!fd_write(nextout, line, strlen(line))) {
                         err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
