@@ -353,23 +353,10 @@ void mclear()
     }
     space[x] = 0;
 
-#if defined(__CYGWIN__)
-    for(x=0; x<maxx-1; x++) {
-       space2[x] = ' ';
-    }
-    space2[x] = 0;
-
-    mattron(0);
-    for(y=0; y<maxy-1; y++) {
-       mmvprintw(y, 0, space);
-    }
-    mmvprintw(maxy-1, 0, space2);
-#else
     mattron(0);
     for(y=0; y<maxy; y++) {
        mmvprintw(y, 0, space);
     }
-#endif
 
     gX = 0;
     gY = 0;
@@ -390,24 +377,9 @@ void mclear_online(int y)
 
     const int maxx = mgetmaxx();
 
-#if defined(__CYGWIN__)
-    const int maxy = mgetmaxy();
-
-    if(y == maxy-1) {
-        for(x=0; x<maxx-1; x++) {
-            space[x] = ' ';
-        }
-    }
-    else {
-        for(x=0; x<maxx; x++) {
-            space[x] = ' ';
-        }
-    }
-#else
     for(x=0; x<maxx; x++) {
         space[x] = ' ';
     }
-#endif
     space[x] = 0;
 
     mattron(0);
@@ -1277,11 +1249,7 @@ int mgetmaxy()
     struct winsize ws;
     ioctl(STDOUT_FILENO, TIOCGWINSZ, &ws);
 
-#if defined(__CYGWIN__)
-    return ws.ws_row-1;
-#else
     return ws.ws_row;
-#endif
 }
 
 static int gKeyBuf[1024];
@@ -1387,32 +1355,6 @@ static int y = 0;
                     }
                 }
 
-
-#if defined(__CYGWIN__)
-                fd_set mask;
-
-                FD_ZERO(&mask);
-                FD_SET(gMCTtyFd, &mask);
-
-                struct timeval tv;
-                tv.tv_sec = 0;
-                tv.tv_usec = 0;
-
-                select(gMCTtyFd + 1, &mask, NULL, NULL, &tv);
-
-                if(FD_ISSET(gMCTtyFd, &mask)) {
-                    if((n2 = ttyread(tmp, 10)) < 0) {
-                        /*
-                        perror("read1");
-                        mexit(1);
-                        */
-                        return -1;
-                    }
-                }
-                else {
-                    n2 = 0;
-                }
-#else
                 if((n2 = ttyread(tmp, 10)) < 0) {
                     /*
                     perror("read2");
@@ -1420,7 +1362,6 @@ static int y = 0;
                     */
                     return -1;
                 }
-#endif
 
                 if(n2 != 0)
                     for(i=0; i<n2; i++) gKeyBuf[gKeyBufNum++] = tmp[i];
@@ -1521,57 +1462,6 @@ y++;
 
             if(block) {
                 while(n == 0) {
-#if defined(__CYGWIN__)
-                    fd_set mask;
-
-                    FD_ZERO(&mask);
-                    FD_SET(gMCTtyFd, &mask);
-
-                    struct timeval tv;
-                    tv.tv_sec = 0;
-                    tv.tv_usec = 0;
-
-                    select(gMCTtyFd+1, &mask, NULL, NULL, &tv);
-
-                    if(FD_ISSET(gMCTtyFd, &mask)) {
-                        if((n = ttyread(buf, 10)) < 0) {
-switch(errno) {
-case EIO:
-puts("EIO");
-break;
-
-case EAGAIN:
-puts("EAGAIN");
-break;
-
-case EBADF:
-puts("EBADF");
-break;
-
-case EFAULT:
-puts("EFAULT");
-break;
-
-case EINTR:
-puts("EINTR");
-break;
-
-case EINVAL:
-puts("EINVAL");
-break;
-
-case EISDIR:
-puts("EISDIR");
-break;
-}
-                            perror("read3");
-                            exit(1);
-                        }
-                    }
-                    else {
-                        n = 0;
-                    }
-#else
                     fd_set mask;
 
                     FD_ZERO(&mask);
@@ -1614,38 +1504,13 @@ break;
                             exit(1);
                         }
                     }
-
-#endif
                 }
             }
             else {
-#if defined(__CYGWIN__)
-                fd_set mask;
-
-                FD_ZERO(&mask);
-                FD_SET(gMCTtyFd, &mask);
-
-                struct timeval tv;
-                tv.tv_sec = 0;
-                tv.tv_usec = 0;
-
-                select(gMCTtyFd+1, &mask, NULL, NULL, &tv);
-
-                if(FD_ISSET(gMCTtyFd, &mask)) {
-                    if((n = ttyread(buf, 10)) < 0) {
-                        perror("read5");
-                        exit(1);
-                    }
-                }
-                else {
-                    n = 0;
-                }
-#else
                 if((n = ttyread(buf, 10)) < 0) {
                     perror("read6");
                     exit(1);
                 }
-#endif
                 if(n == 0) {
                     *meta = 0;
                     return -1;
@@ -1690,33 +1555,10 @@ break;
                         break;
                     }
                     else {
-#if defined(__CYGWIN__)
-                        fd_set mask;
-
-                        FD_ZERO(&mask);
-                        FD_SET(gMCTtyFd, &mask);
-
-                        struct timeval tv;
-                        tv.tv_sec = 0;
-                        tv.tv_usec = 0;
-
-                        select(gMCTtyFd + 1, &mask, NULL, NULL, &tv);
-
-                        if(FD_ISSET(gMCTtyFd, &mask)) {
-                            if((n2 = ttyread(tmp, 10)) < 0) {
-                                perror("read7-2");
-                                exit(1);
-                            }
-                        }
-                        else {
-                            n2 = 0;
-                        }
-#else
                         if((n2 = ttyread(tmp, 10)) < 0) {
                             perror("read8-2");
                             exit(1);
                         }
-#endif
 
                         if(n2 != 0)
                             for(i=0; i<n2; i++) buf[n++] = tmp[i];
@@ -1796,35 +1638,10 @@ break;
                             }
                         }
 
-
-    #if defined(__CYGWIN__)
-                        fd_set mask;
-
-                        FD_ZERO(&mask);
-                        FD_SET(gMCTtyFd, &mask);
-
-                        struct timeval tv;
-                        tv.tv_sec = 0;
-                        tv.tv_usec = 0;
-
-                        select(gMCTtyFd + 1, &mask, NULL, NULL, &tv);
-
-                        if(FD_ISSET(gMCTtyFd, &mask)) {
-                            if((n2 = ttyread(tmp, 10)) < 0) {
-                                perror("read7");
-                                exit(1);
-                            }
-                        }
-                        else {
-                            n2 = 0;
-                        }
-    #else
-
                         if((n2 = ttyread(tmp, 10)) < 0) {
                             perror("read8");
                             exit(1);
                         }
-    #endif
 
                         if(n2 != 0)
                             for(i=0; i<n2; i++) buf[n++] = tmp[i];
@@ -2078,30 +1895,18 @@ int mis_raw_mode()
 
 void msave_screen()
 {
-#if defined(__CYGWIN__)
-    char buf[128];
-    snprintf(buf, 128, "\033%d\033[?47h", 7);
-    ttywrite(buf);
-#else
     char* str = tigetstr("smcup");
     if(str) {
         ttywrite(str);
     }
-#endif
 }
 
 void mrestore_screen()
 {
-#if defined(__CYGWIN__)
-    char buf[128];
-    snprintf(buf, 128, "\033[2J\033[?47l\033%d", 8);
-    ttywrite(buf);
-#else
     char* str = tigetstr("rmcup");
     if(str) {
         ttywrite(str);
     }
-#endif
 }
 
 
